%global mingw_build_ucrt64 1

%{?mingw_package_header}

# Steps:
# - Perform (scratch) build with bootstrap=1
# - Update the standard-dlls-xxx files as documented below, and rebuild with bootstrap=0
%global bootstrap 0

Name:           mingw-crt
Version:        10.0.0
Release:        %mkrel 2
Summary:        MinGW Windows cross-compiler runtime

License:        Public Domain and ZPLv2.1
Group:          Development/Other
URL:            https://mingw-w64.sourceforge.net/
Source0:        http://downloads.sourceforge.net/mingw-w64/mingw-w64-v%{version}.tar.bz2


# Note about standard dlls
# ------------------------------------------------------------
#
# We want to be able to build & install mingw32 libraries without
# necessarily needing to install wine.  (And certainly not needing to
# install Windows!)  There is no requirement to have wine installed in
# order to use the mingw toolchain to develop software (i.e. to
# compile more stuff on top of it), so why require that?
#
# So for expediency, this base package provides the "missing" DLLs
# from Windows.  Another way to do it would be to exclude these
# proprietary DLLs in our find-requires checking script - essentially
# it comes out the same either way.
#
# (rpm -ql mingw32-crt | grep '\.a$' | while read f ; do i686-w64-mingw32-dlltool   -I $f 2>/dev/null ; done) | sort | uniq | tr A-Z a-z > standard-dlls-mingw32
Source1:       standard-dlls-mingw32
# (rpm -ql mingw64-crt | grep '\.a$' | while read f ; do x86_64-w64-mingw32-dlltool -I $f 2>/dev/null ; done) | sort | uniq | tr A-Z a-z > standard-dlls-mingw64
Source2:       standard-dlls-mingw64
# (rpm -ql ucrt64-crt | grep '\.a$' | while read f ; do x86_64-w64-mingw32ucrt-dlltool -I $f 2>/dev/null ; done) | sort | uniq | tr A-Z a-z > standard-dlls-ucrt64
Source3:       standard-dlls-ucrt64

# Fix build failure with gcc11
Patch0:         mingw-crt_gcc11.patch

BuildArch:      noarch

BuildRequires:  make

BuildRequires:  mingw32-filesystem >= 133
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-headers
BuildRequires:  mingw32-gcc

BuildRequires:  mingw64-filesystem >= 133
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-headers
BuildRequires:  mingw64-gcc

BuildRequires:  ucrt64-filesystem >= 133
BuildRequires:  ucrt64-binutils
BuildRequires:  ucrt64-headers
BuildRequires:  ucrt64-gcc

%description
MinGW Windows cross-compiler runtime, base libraries.


%package -n mingw32-crt
Summary:        MinGW Windows cross-compiler runtime for the win32 target
Requires:       mingw32-filesystem >= 133
%if 0%{?bootstrap:1}
Provides:       %(sed "s/\(.*\)/mingw32(\1) /g" %{SOURCE1} | tr "\n" " ")
Provides:       mingw32(mscoree.dll)
%endif

%description -n mingw32-crt
MinGW Windows cross-compiler runtime, base libraries for the win32 target.

%package -n mingw64-crt
Summary:        MinGW Windows cross-compiler runtime for the win64 target
Requires:       mingw64-filesystem >= 133
%if 0%{?bootstrap:1}
Provides:       %(sed "s/\(.*\)/mingw64(\1) /g" %{SOURCE2} | tr "\n" " ")
Provides:       mingw64(mscoree.dll)
%endif

%description -n mingw64-crt
MinGW Windows cross-compiler runtime, base libraries for the win64 target.

%package -n ucrt64-crt
Summary:        MinGW Windows cross-compiler runtime for the win64 target
Requires:       ucrt64-filesystem >= 133
%if 0%{?bootstrap:1}
Provides:       %(sed "s/\(.*\)/ucrt64(\1) /g" %{SOURCE3} | tr "\n" " ")
Provides:       ucrt64(mscoree.dll)
%endif

%description -n ucrt64-crt
MinGW Windows cross-compiler runtime, base libraries for the win64 target.


%prep
%autosetup -p1 -n mingw-w64-v%{version}


%build
pushd mingw-w64-crt
    # Filter out -fstack-protector and -lssp from LDFLAGS as libssp is not yet potentially built with the bootstrap gcc
    MINGW32_LDFLAGS="`echo %{mingw32_ldflags} | sed 's|-fstack-protector||' | sed 's|-lssp||'`"
    MINGW64_LDFLAGS="`echo %{mingw64_ldflags} | sed 's|-fstack-protector||' | sed 's|-lssp||'`"
    MINGW64_CONFIGURE_ARGS="--disable-lib32"
    UCRT64_LDFLAGS="`echo %{ucrt64_ldflags} | sed 's|-fstack-protector||' | sed 's|-lssp||'`"
    UCRT64_CONFIGURE_ARGS="--disable-lib32 --with-default-msvcrt=ucrt"
    %mingw_configure
    %mingw_make_build
popd


%install
pushd mingw-w64-crt
    %mingw_make_install
popd

# Dunno what to do with these files
rm -rf %{buildroot}%{mingw32_includedir}/*.c
rm -rf %{buildroot}%{mingw64_includedir}/*.c
rm -rf %{buildroot}%{ucrt64_includedir}/*.c


%files -n mingw32-crt
%license COPYING DISCLAIMER DISCLAIMER.PD
%{mingw32_libdir}/*

%files -n mingw64-crt
%license COPYING DISCLAIMER DISCLAIMER.PD
%{mingw64_libdir}/*
 
%files -n ucrt64-crt
%license COPYING DISCLAIMER DISCLAIMER.PD
%{ucrt64_libdir}/*


%changelog
* Sun May 08 2022 tv <tv> 10.0.0-2.mga9
+ Revision: 1856740
- Provide standard DLLs
- Spec cleanups

* Thu Apr 28 2022 tv <tv> 10.0.0-1.mga9
+ Revision: 1854838
- Update to 10.0.0

* Sun Mar 27 2022 tv <tv> 9.0.0-4.mga9
+ Revision: 1829327
- Race condition with parallel build
- Rebuild with gcc12

* Mon Mar 21 2022 umeabot <umeabot> 9.0.0-3.mga9
+ Revision: 1816485
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 tv <tv> 9.0.0-2.mga9
+ Revision: 1787173
- Add UCRT64 target

* Fri Oct 22 2021 tv <tv> 9.0.0-1.mga9
+ Revision: 1752608
- Update to 9.0.0

* Mon Nov 02 2020 akien <akien> 8.0.0-1.mga9
+ Revision: 1641656
- Version 8.0.0

* Thu Sep 24 2020 tv <tv> 7.0.0-1.mga8
+ Revision: 1629800
- 7.0.0
+ danf <danf>
- Switch URLs from http: to https:

* Sat Feb 15 2020 umeabot <umeabot> 6.0.0-2.mga8
+ Revision: 1526925
- Mageia 8 Mass Rebuild

* Sat Jul 06 2019 daviddavid <daviddavid> 6.0.0-1.mga8
+ Revision: 1418948
- new version: 6.0.0

* Thu Sep 20 2018 umeabot <umeabot> 5.0.4-2.mga7
+ Revision: 1279526
- Mageia 7 Mass Rebuild

* Sun Aug 05 2018 daviddavid <daviddavid> 5.0.4-1.mga7
+ Revision: 1247536
- new version: 5.0.4

* Thu Apr 07 2016 daviddavid <daviddavid> 5.0-0.1.rc2.1.mga6
+ Revision: 999110
- fix release tag

* Tue Apr 05 2016 tv <tv> 5.0-0.1.rc2.mga6.mga6
+ Revision: 998649
- new release

* Mon Feb 08 2016 umeabot <umeabot> 3.0.0-5.mga6
+ Revision: 943086
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.0.0-4.mga5
+ Revision: 748525
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.0.0-3.mga5
+ Revision: 682417
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.0.0-2.mga4
+ Revision: 536079
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 3.0.0-1.mga4
+ Revision: 483200
- imported package mingw-crt

